@@ -106,6 +106,12 @@ module MikuTwitter::APIShortcuts
     request.messages(args)
   end
 
+  def retweeted_users(args = {})
+    args[:id] = args[:status_id] if args[:status_id]
+    request = self/:statuses/:retweeters/:ids
+    cursor_pager(request, :paged_ids, :ids, args).next do |ids|
+      Thread.new{ User.findbyid(ids) } end end
+
   defshortcut :rate_limit_status, "account/rate_limit_status", :json
 
   defshortcut :verify_credentials, "account/verify_credentials", :user
@@ -116,17 +122,42 @@ module MikuTwitter::APIShortcuts
 
   def update(message)
     text = message[:message]
-    replyto = message[:replyto]
-    receiver = message[:receiver]
+    replyto = message[:replyto] && Message.generate(message[:replyto])
+    receiver = message[:receiver] && User.generate(message[:receiver])
     iolist = message[:mediaiolist]
+    is_reply = !!(receiver || replyto)
     data = {:status => text }
-    data[:in_reply_to_user_id] = User.generate(receiver)[:id].to_s if receiver
-    data[:in_reply_to_status_id] = Message.generate(replyto)[:id].to_s if replyto
+    data[:in_reply_to_user_id] = receiver.id if receiver
+    data[:in_reply_to_status_id] = replyto.id if replyto
+    if is_reply && UserConfig[:auto_populate_reply_metadata]
+      data[:auto_populate_reply_metadata] = true
+      forecast_receivers = Set.new
+      exclude_receivers = Set.new
+      if replyto
+        replyto.each_ancestor.each do |m|
+          forecast_receivers << m.user
+          forecast_receivers.merge(m.receive_user_screen_names.map{|sn| User.findbyidname(sn) }.compact)
+        end
+      end
+      mentions = text.match(%r[\A((?:@[a-zA-Z0-9_]+\s+)+)])
+      if mentions
+        specific_screen_names = mentions[1].split(/\s+/).map{|s|s[1, s.size]}
+        exclude_receivers += forecast_receivers.reject{|u| specific_screen_names.include?(u.idname) }
+        text = [*(specific_screen_names - forecast_receivers.map(&:idname)).map{|s|"@#{s}"}, text[mentions.end(0),text.size]].join(' '.freeze)
+        data[:status] = text
+      end
+      data[:exclude_reply_user_ids] = exclude_receivers.map(&:id).join(',') unless exclude_receivers.empty?
+    end
     if iolist and !iolist.empty?
       Deferred.when(*iolist.collect{ |io| upload_media(io) }).next{|media_list|
         data[:media_ids] = media_list.map{|media| media['media_id'] }.join(",")
         (self/'statuses/update').message(data) }
     else
+      attachment_url = text.match(%r[\A(.+?)\s+(https?://twitter.com/(?:#!/)?(?:[a-zA-Z0-9_]+)/status(?:es)?/(?:\d+)(?:\?.*)?)\Z]m)
+      if attachment_url
+        data[:attachment_url] = attachment_url[2]
+        data[:status] = attachment_url[1]
+      end
       (self/'statuses/update').message(data) end end
   alias post update
 
@@ -194,6 +225,7 @@ module MikuTwitter::APIShortcuts
     parsed_url = Addressable::URI.parse(url)
     stream_access_token = access_token("#{parsed_url.scheme}://#{parsed_url.host}")
     http = stream_access_token.consumer.http
+    http.read_timeout = 90
     http.ssl_version = 'TLSv1'
     consumer = stream_access_token.consumer
     request = consumer.create_signed_request(:post,
