@@ -17,7 +17,7 @@ class Gdk::SubPartsRetweet < Gdk::SubPartsVoter
   end
 
   def title_icon
-    Gdk::Pixbuf.new(Skin.get("retweet.png"), @icon_width, @icon_height) end
+    GdkPixbuf::Pixbuf.new(file: Skin.get("retweet.png"), width: @icon_width, height: @icon_height) end
 
   def name
     :retweeted end
