@@ -175,7 +175,7 @@ module Gtk
       @to.select{|m|m.is_a?(Message)}.each{ |message|
         w_reply = Gtk::HBox.new
         itv = Gtk::IntelligentTextview.new(message.to_show, 'font' => :mumble_basic_font)
-        itv.get_background = lambda{ get_backgroundstyle(message) }
+        itv.style_generator = lambda{ get_backgroundstyle(message) }
         itv.bg_modifier
         ev = Gtk::EventBox.new
         ev.style = get_backgroundstyle(message)
@@ -264,7 +264,7 @@ module Gtk
 
     # _related_widgets_ のうちどれもアクティブではなく、フォーカスが外れたら削除される設定の場合、このウィジェットを削除する
     def destroy_if_necessary(*related_widgets)
-      if(not(frozen?) and not([widget_post, *related_widgets].compact.any?{ |w| w.focus? }) and destructible?)
+      if(not(frozen? or destroyed?) and not([widget_post, *related_widgets].compact.any?{ |w| w.focus? }) and destructible?)
         destroy
         true end end
 
@@ -289,16 +289,50 @@ module Gtk
 
     def remain_charcount
       if not widget_post.destroyed?
-        footer = if use_blind_footer? then UserConfig[:footer].size else 0 end
-        text = widget_post.buffer.text
+        text = trim_hidden_regions(widget_post.buffer.text + UserConfig[:footer])
         Twitter::Extractor.extract_urls(text).map{|url|
           if url.length < posted_url_length(url)
             -(posted_url_length(url) - url.length)
           else
             url.length - posted_url_length(url) end
-        }.inject(140 - text.size - footer, &:+)
+        }.inject(140 - text.size, &:+)
       end end
 
+    def trim_hidden_regions(text)
+      trim_hidden_header(trim_hidden_footer(text))
+    end
+
+    # 文字列からhidden headerを除いた文字列を返す。
+    # hidden headerが含まれていない場合は、 _text_ を返す。
+    def trim_hidden_header(text)
+      return text unless UserConfig[:auto_populate_reply_metadata]
+      mentions = text.match(%r[\A((?:@[a-zA-Z0-9_]+\s+)+)])
+      forecast_receivers_sn = Set.new
+      if reply?
+        @to.first.each_ancestor.each do |m|
+          forecast_receivers_sn << m.user.idname
+          forecast_receivers_sn.merge(m.receive_user_screen_names)
+        end
+      end
+      if mentions
+        specific_screen_names = Set.new(mentions[1].split(/\s+/).map{|s|s[1, s.size]})
+        [*(specific_screen_names - forecast_receivers_sn).map{|s|"@#{s}"}, text[mentions.end(0),text.size]].join(' '.freeze)
+      else
+        text
+      end
+    end
+
+    # 文字列からhidden footerを除いた文字列を返す。
+    # hidden footerが含まれていない場合は、 _text_ を返す。
+    def trim_hidden_footer(text)
+      attachment_url = text.match(%r[\A(.*?)\s+(https?://twitter.com/(?:#!/)?(?:[a-zA-Z0-9_]+)/status(?:es)?/(?:\d+)(?:\?.*)?)\Z]m)
+      if attachment_url
+        attachment_url[1]
+      else
+        text
+      end
+    end
+
     # URL _url_ がTwitterに投稿された時に何文字としてカウントされるかを返す
     # ==== Args
     # [url] String URL
@@ -310,7 +344,7 @@ module Gtk
     def focus_out_event(widget, event=nil)
       options = @options
       Delayer.new{
-        if(not(frozen?) and not(options.has_key?(:postboxstorage)) and post_is_empty?)
+        if(not(frozen? or destroyed?) and not(options.has_key?(:postboxstorage)) and post_is_empty?)
           destroy_if_necessary(widget_send, widget_tool, *@reply_widgets) end }
       false end
 
